@@ -21,10 +21,11 @@ find . -iname '*.o' -delete
 find plugins -iname '*.w?x' -delete
 find plugins -iname '*.dsx' -delete
 find plugins -iname '*.or'  -delete
-find plugins -iname '*.res'  -delete
+find plugins -iname '*.res' -not -path "*/src/*" -delete
 find plugins -iname '*.a'  -delete
 rm -f src/doublecmd.res doublecmd
 rm -f tools/extractdwrflnfo
+rm -f plugins/wcx/unrar/lib/rarconfdlg.lfm
 rm -f plugins/wcx/zip/lib/ZipConfDlg.lfm
 rm -f plugins/wcx/zip/lib/abresstring.rs?
 rm -f plugins/wfx/ftp/lib/FtpConfDlg.lfm
